@@ -142,7 +142,7 @@ class User(AbstractBaseUser, PermissionsMixin):
         return filtered_send_mail(
             '_',
             '_',
-            'info@rippleenergy.com',
+            '',
             [self.email],
             html_message='_',
             sg_template_id=settings.SG_TL_EMAIL_VERIFICATION,
@@ -183,7 +183,7 @@ class User(AbstractBaseUser, PermissionsMixin):
         return filtered_send_mail(
             '_',
             '_',
-            'info@rippleenergy.com',
+            '',
             [self.email],
             html_message='_',
             sg_template_id=settings.SG_TL_PASSWORD_CHANGED_CONFIRMED,
@@ -204,7 +204,7 @@ class User(AbstractBaseUser, PermissionsMixin):
         return filtered_send_mail(
             '_',
             '_',
-            'info@rippleenergy.com',
+            '',
             [old_email_address],
             html_message='_',
             sg_template_id=settings.SG_TL_EMAIL_CHANGED_NOTIFY,
